@@ -1,7 +1,7 @@
 #!/bin/bash
 
-# rust create_release v0.6.1
-# 2024-10-21
+# rust create_release v0.6.2
+# 2025-02-22
 
 STAR_LINE='****************************************'
 CWD=$(pwd)
@@ -202,24 +202,28 @@ check_cross() {
 	fi
 }
 
+# Build, using cross-rs, for linux x86 musl
 cross_build_x86_linux() {
 	check_cross
 	echo -e "${YELLOW}cross build --target x86_64-unknown-linux-musl --release${RESET}"
 	cross build --target x86_64-unknown-linux-musl --release
 }
 
+# Build, using cross-rs, for linux arm64 musl
 cross_build_aarch64_linux() {
 	check_cross
 	echo -e "${YELLOW}cross build --target aarch64-unknown-linux-musl --release${RESET}"
 	cross build --target aarch64-unknown-linux-musl --release
 }
 
+# Build, using cross-rs, for linux armv6 musl
 cross_build_armv6_linux() {
 	check_cross
 	echo -e "${YELLOW}cross build --target arm-unknown-linux-musleabihf --release${RESET}"
 	cross build --target arm-unknown-linux-musleabihf --release
 }
 
+# Build, using cross-rs, for windows x86
 cross_build_x86_windows() {
 	check_cross
 	echo -e "${YELLOW}cross build --target x86_64-pc-windows-gnu --release${RESET}"
@@ -266,6 +270,34 @@ check_allow_unused() {
 	fi
 }
 
+# build container for amd64 platform
+build_container_amd64() {
+	echo -e "${YELLOW}docker build  --platform linux/amd64 --no-cache -t oxker_amd64 --no-cache -f containerised/Dockerfile .; docker save -o /tmp/oxker_amd64.tar oxker_amd64${RESET}"
+	docker build --platform linux/amd64 --no-cache -t oxker_amd64 -f containerised/Dockerfile .
+	docker save -o /tmp/oxker_amd64.tar oxker_amd64
+}
+# build container for aarm64 platform
+build_container_arm64() {
+	echo -e "${YELLOW}docker build  --platform linux/arm64 --no-cache -t oxker_arm64 --no-cache -f containerised/Dockerfile .; docker save -o /tmp/oxker_arm64.tar oxker_arm64${RESET}"
+	docker build --platform linux/arm64 --no-cache -t oxker_arm64 -f containerised/Dockerfile .
+	docker save -o /tmp/oxker_arm64.tar oxker_arm64
+}
+# build container for armv6 platform
+build_container_armv6() {
+	echo -e "${YELLOW}docker build  --platform linux/arm/v6 --no-cache -t oxker_armv6 --no-cache -f containerised/Dockerfile .; docker save -o /tmp/oxker_armv6.tar oxker_armv6${RESET}"
+	docker build --platform linux/arm/v6 --no-cache -t oxker_armv6 -f containerised/Dockerfile .
+	docker save -o /tmp/oxker_armv6.tar oxker_armv6
+}
+
+# Build all the containers, this get executed in the github action
+build_container_all() {
+	build_container_amd64
+	ask_continue
+	build_container_arm64
+	ask_continue
+	build_container_armv6
+}
+
 # Full flow to create a new release
 release_flow() {
 	check_allow_unused
@@ -276,6 +308,7 @@ release_flow() {
 
 	cargo_test
 	cross_build_all
+	build_container_all
 	cargo_publish_dry_run
 
 	cd "${CWD}" || error_close "Can't find ${CWD}"
@@ -379,6 +412,45 @@ build_choice() {
 			;;
 		esac
 	done
+}
+
+build_container_choice() {
+	cmd=(dialog --backtitle "Choose option" --radiolist "choose" 14 80 16)
+	options=(
+		1 "x86 " off
+		2 "aarch64" off
+		3 "armv6" off
+		4 "all" off
+	)
+	choices=$("${cmd[@]}" "${options[@]}" 2>&1 >/dev/tty)
+	exitStatus=$?
+	clear
+	if [ $exitStatus -ne 0 ]; then
+		exit
+	fi
+	for choice in $choices; do
+		case $choice in
+		0)
+			exit
+			;;
+		1)
+			build_container_amd64
+			exit
+			;;
+		2)
+			build_container_arm64
+			exit
+			;;
+		3)
+			build_container_armv6
+			exit
+			;;
+		4)
+			build_container_all
+			exit
+			;;
+		esac
+	done
 
 }
 
@@ -388,6 +460,7 @@ main() {
 		1 "test" off
 		2 "release" off
 		3 "build" off
+		4 "docker builds" off
 	)
 	choices=$("${cmd[@]}" "${options[@]}" 2>&1 >/dev/tty)
 	exitStatus=$?
@@ -414,6 +487,11 @@ main() {
 			main
 			break
 			;;
+		4)
+			build_container_choice
+			main
+			break
+			;;
 		esac
 	done
 }
